// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
//	test the AbsorptionDataServer class
//
#include <iostream>
#include <cassert>
#include "CalServer.h"
#include "PhysicalConstants.h"
#include "ContaminantDataServer.h"

using namespace std;

namespace {
bool isClose(double a, double b)
{
    return fabs(a)/fabs(b)-1. < 1.e-5;
}
}

int main()
{
	//	setup the the Cal server
	const Xmm::Instrument instrument = Xmm::EMOS1;
	calServer.setInstrument(instrument);
	calServer.state()->ccd()->set(1);
	calServer.state()->node()->set(EMOScam::PRIMARY_NODE);

	//	get the ContaminationDataServer
        ContaminantDataServer *cnds = 0; cnds = calServer.getAtom(cnds);

       // double mjd[] = {55000.0,56000.0,57000.0};

        //ContaminantTransmissionCurve *ctc = cnds->at(time[0]);
        ContaminantTransmissionCurve *ctc = cnds->at(56000.0);

	double e[] = { 48.9609, 1000., 5000., 10000., 15000. };

        cout<<"MOS-1 at MJD=56000"<<endl;
	for (unsigned n=0; n<5; ++n) 
            cout<<e[n]<<" eV: "<<ctc->transmission(e[n])<<endl;

        delete ctc;
        calServer.releaseAtom(cnds);

       // Try MOS-2
        calServer.setInstrument(Xmm::EMOS2);

        cnds = calServer.getAtom(cnds);
        ctc = cnds->at(52000.0);

        cout<<"MOS-2 at MJD=52000"<<endl;
        for (unsigned n=0; n<5; ++n)
            cout<<e[n]<<" eV: "<<ctc->transmission(e[n])<<endl;

        delete ctc;

        ctc = cnds->at(58000.0);

        cout<<"MOS-2 at MJD=58000"<<endl;
        for (unsigned n=0; n<5; ++n)
            cout<<e[n]<<" eV: "<<ctc->transmission(e[n])<<endl;

        delete ctc;
        calServer.releaseAtom(cnds);

	return 0;
}
