// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
//	test the AbsorptionDataServer class
//
#include <iostream>
#include <cassert>
#include "CalServer.h"
#include "Ccf.h"
#include "FilterDataServer.h"

using namespace std;

namespace {
bool isClose(double a, double b)
{
    return fabs(a)/fabs(b)-1. < 1.e-5;
}
}

int main()
{
	//	setup the the Cal server
	const Xmm::Instrument instrument = Xmm::EMOS1;
	calServer.setInstrument(instrument);
	calServer.state()->ccd()->set(1);
	calServer.state()->node()->set(EMOScam::PRIMARY_NODE);
	calServer.state()->filter()->set(Xmm::THIN1);

	//	get the FilterDataServer
	FilterDataServer *fds = 0; fds = calServer.getAtom(fds);

	double e[] = { 100., 1000., 3000., 5000., 9000. },
		   f1v[] = { 0.117634, 0.921516, 0.988655, 0.997349, 0.999536 },
		   f2v[] = { 0.145573, 0.92253, 0.988715, 0.997357, 0.999537 };

	const FilterTransmissionCurve &fc = fds->at(0., 0.);
	for (unsigned n=0; n<NUM_OF(e); ++n) {
		double ft = fc.transmission(e[n]),
			   fi = fc.transmission(e[n], e[n]+10.);
		cout<<"filter transmission at E="<<e[n]<<"="<<ft
			<<" - weighted integral over 10 eV: "<<fi<<endl;
		assert(isClose(ft, f1v[n]) && isClose(fi, f2v[n]));
	}

	//	check outside FOV response
	const FilterTransmissionCurve &outsideFOV = fds->at(1500., 0.);
	cout<<"outside FOV transmission E=100 : "
		<<outsideFOV.transmission(100.)<<endl;
	cout<<"outside FOV transmission E=2000: "
		<<outsideFOV.transmission(2000.)<<endl;

	errstr<<"CCF constituents accessed during CAL livetime:\n"
		  <<calServer.ccfAccessLog()<<endl
		  <<Sas::message(Msg::App, Msg::Always);

	return 0;
}







