// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
//	test the cal rawx2mm calls
//
#include <iostream>
#include <iomanip>
#include <cstdlib>
#include "CalServer.h"
#include "Xmm.h"
#include "GeometryDataServer.h"
#include "common.h"

using namespace std;

int main(int argc, char **argv)
{
	if (argc != 4) {
		cerr<<"Usage: "<<argv[0]<<" <pixX> <pixY> <ccd>\n";
		return 1;
	}

	calServer.setInstrument(Xmm::EMOS1);
	Ccd ccd = atoi(argv[3]);
	calServer.state()->ccd()->set(ccd);
	calServer.state()->randomize()->set(false);
	calServer.state()->temperature()->set(293.);
	calServer.state()->temperatureCamera()->set(293.);

	double xmm, ymm, zmm;
	CalReal64Vector x(&xmm, 1), y(&ymm, 1), z(&zmm, 1);
	short xint = atoi(argv[1]), yint = atoi(argv[2]);
	CalInt16Vector xpix(&xint, 1), ypix(&yint, 1);
	cout<<xint<<'/'<<yint<<'['<<ccd<<"] = ";

	GeometryDataServer *cdf = 0; cdf = calServer.getAtom(cdf);
	XmmPixelList pix = cdf->chipCoordList(xpix, ypix);
	XmmCartesianPointList cpl = pix.toCamCoord1(x, y, z);
	cout<<xmm<<'/'<<ymm<<'/'<<zmm<<" = ";

	ccd = cdf->onCcd(xmm, ymm);
	pix = cpl.toChipCoord();
	cout<<pix.x()[0]<<'/'<<pix.y()[0]<<'['<<ccd<<"]\n";

	return 0;
}
