// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
//	test RGA-related stuff; embryonic at the moment; add more test in due
//	time
//
#include <iostream>
#include <iomanip>
#include <cmath>
#include "CalCommon.h"
#include "CalServer.h"
#include "GratingDataServer.h"
#include "Xmm.h"

using namespace std;

static bool isClose(double a, double b)
{
    return fabs(a)/fabs(b)-1. < 1.e-5;
}

int main(int argc, char **argv)
{
	if (argc>1)
		calServer.ccf()->registerNewCifEntry(argv[1]);

	const double E = 1100,
				 ALPHA = 2.7*DEG_TO_RAD;
	const int ORDER = -1;

	calServer.setInstrument(Xmm::RGS1);
	GratingDataServer *gds = 0; gds = calServer.getAtom(gds);

	double betaM = gds->beta(ALPHA, ORDER, E),
		   order = gds->order(ALPHA, betaM, E),
		   energy = gds->energy(ALPHA, betaM, ORDER);

	cout<<"order="<<order<<endl;
	cout<<"energy="<<energy<<endl;
	assert(isClose(order, ORDER));
	assert(isClose(energy, E));

	//	misalignment figure distribution
	double chromaticMagnification = 1.;
	const double NBETA = 10000.,
				 DELTA_BETA = .5,	//	beta span
				 binWidth = DELTA_BETA/NBETA;

	Spectrum spec(gds->misalignmentFigureDistribution(7.,
												   binWidth*DEG_TO_RAD,
												   chromaticMagnification));
	int N = spec.size();
	for (int n=0; n<N; ++n)
		cout<<setprecision(6)<<n-N/2<<' '<<spec[n]<<endl;
	return 0;
}

