// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//					   (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	SWCXImageDataServer.h --- Cal atom to return swcx images
//
//	DESCRIPTION:
//
//	CHANGE HISTORY:
//		RDS, 2016-09-26: 1.0: - original
//
//	AUTHOR:
//		R. Saxton
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al., 
//
#ifndef SWCXImage_H
#define SWCXImage_H

#include "Ccf.h"
#include "CalAtomsBase.h"
#include "Image.h"

#include <vector>
#include <map>

//
//	---( mode parameters )------------------------------------------------
//
class SWCXImageDataServer : public CalAtom,
        public virtual CalChild<CalAtomCollection<SWCXImageDataServer> > { 
public:

	// Constructor
	SWCXImageDataServer(  multimap<const string,
                                           SImage> swcxImage,
                        CalAtomCollection<SWCXImageDataServer> *parent=0);

	static unsigned id() { return Ccf::SWCX; };

        // Return requested map for this emission line
        const SImage getSWCXImage(string &line);

private:

        // A map containing all the swcx images
        // for each line
        multimap<const string, SImage> _swcxImage;
};


#endif

